Skip to contents

Pre-computed pilot data from THP-1 monocytic leukemia cells generated using 10x Chromium technology. Contains baseline gene expression parameters and library size information for power analysis of CRISPR-based perturbation experiments.

Usage

THP1_Yao

Format

A list with 3 elements:

baseline_expression_stats

Data frame with gene expression data (16,366 genes × 3 columns):

  • response_id: Character vector of Ensembl gene IDs

  • relative_expression: Numeric vector of relative expression levels (TPM/1e6 scale)

  • expression_size: Numeric vector of dispersion parameters (theta)

library_parameters

List containing saturation curve parameters estimated using preseqR. Data-adaptively selected method: ZTNB. Contains:

  • method_used: "ZTNB" - Zero-truncated negative binomial method

  • L: 4.96e8 - Total expected distinct UMIs at saturation

  • size: 1.79 - ZTNB shape parameter

  • mu: 0.124 - ZTNB mean parameter

  • reads_norm: 10,930 - Normalization constant (reads per cell)

  • n_cells: 5,608 - Number of cells in pilot data

  • UMI_per_cell_at_saturation: 88,390 - Maximum UMI per cell at infinite sequencing depth

mapping_efficiency

Numeric. Mapping efficiency value (0.677)

Paper: Scalable genetic screening for regulatory circuits using compressed Perturb-seq

Author and Year: Yao et al., 2023

Journal: Nature Biotechnology

Accession: GSE221321

PMID: 36747806

Details

This dataset was generated from THP-1 monocytic leukemia cells using single-cell RNA sequencing with 10x Chromium technology.

Cells Used in Relative Expression Estimate: NT (non-targeting) cells in low-moi condition

See also

get_pilot_data_from_package for accessing this data programmatically

Examples

data(THP1_Yao)
str(THP1_Yao)
#> List of 3
#>  $ baseline_expression_stats:'data.frame':	16366 obs. of  3 variables:
#>   ..$ response_id        : chr [1:16366] "ENSG00000238009" "ENSG00000225880" "ENSG00000230368" "ENSG00000224969" ...
#>   ..$ relative_expression: num [1:16366] 1.86e-07 1.47e-06 1.25e-06 5.84e-06 4.18e-06 ...
#>   ..$ expression_size    : num [1:16366] 298.526 421.671 418.974 0.6 0.193 ...
#>  $ library_parameters       :List of 7
#>   ..$ method_used               : chr "ZTNB"
#>   ..$ L                         : num 4.96e+08
#>   ..$ size                      : num 1.79
#>   ..$ mu                        : num 0.124
#>   ..$ reads_norm                : num 10930
#>   ..$ n_cells                   : num 5608
#>   ..$ UMI_per_cell_at_saturation: num 88390
#>  $ mapping_efficiency       : num 0.677