Skip to contents

Pre-computed pilot data from induced pluripotent stem cells (iPSCs) generated using 10x Chromium technology. Contains baseline gene expression parameters and library size information for power analysis of CRISPR-based perturbation experiments.

Usage

iPSC_Tian

Format

A list with 3 elements:

baseline_expression_stats

Data frame with gene expression data (21,207 genes × 3 columns):

  • response_id: Character vector of Ensembl gene IDs

  • relative_expression: Numeric vector of relative expression levels (TPM/1e6 scale)

  • expression_size: Numeric vector of dispersion parameters (theta)

library_parameters

List containing saturation curve parameters estimated using preseqR. Data-adaptively selected method: ZTNB. Contains:

  • method_used: "ZTNB" - Zero-truncated negative binomial method

  • L: 5.16e8 - Total expected distinct UMIs at saturation

  • size: 2.28 - ZTNB shape parameter

  • mu: 0.55 - ZTNB mean parameter

  • reads_norm: 21,301 - Normalization constant (reads per cell)

  • n_cells: 13,321 - Number of cells in pilot data

  • UMI_per_cell_at_saturation: 38,699 - Maximum UMI per cell at infinite sequencing depth

mapping_efficiency

Numeric. Mapping efficiency value (0.704)

Paper: CRISPR Interference-Based Platform for Multimodal Genetic Screens in Human iPSC-Derived Neurons

Author and Year: Tian et al., 2019

Journal: Neuron

Accession: GSE124703

PMID: 31422865

Details

This dataset was generated from induced pluripotent stem cells (iPSCs) using single-cell RNA sequencing with 10x Chromium technology.

Cells Used in Relative Expression Estimate: All cells in high-moi condition

See also

get_pilot_data_from_package for accessing this data programmatically

Examples

data(iPSC_Tian)
str(iPSC_Tian)
#> List of 3
#>  $ baseline_expression_stats:'data.frame':	21207 obs. of  3 variables:
#>   ..$ response_id        : chr [1:21207] "ENSG00000238009" "ENSG00000241860" "ENSG00000237491" "ENSG00000228794" ...
#>   ..$ relative_expression: num [1:21207] 5.85e-07 1.01e-06 2.89e-06 6.03e-06 5.91e-07 ...
#>   ..$ expression_size    : num [1:21207] 13.1 8.71 426.39 443.33 5.11 ...
#>  $ library_parameters       :List of 7
#>   ..$ method_used               : chr "ZTNB"
#>   ..$ L                         : num 5.16e+08
#>   ..$ size                      : num 2.28
#>   ..$ mu                        : num 0.55
#>   ..$ reads_norm                : num 21301
#>   ..$ n_cells                   : num 13321
#>   ..$ UMI_per_cell_at_saturation: num 38699
#>  $ mapping_efficiency       : num 0.704