Skip to contents

Pre-computed pilot data from iPSC-derived neurons generated using 10x Chromium technology. Contains baseline gene expression parameters and library size information for power analysis of CRISPR-based perturbation experiments.

Usage

iPSC_neuron_Tian

Format

A list with 3 elements:

baseline_expression_stats

Data frame with gene expression data (23,882 genes × 3 columns):

  • response_id: Character vector of Ensembl gene IDs

  • relative_expression: Numeric vector of relative expression levels (TPM/1e6 scale)

  • expression_size: Numeric vector of dispersion parameters (theta)

library_parameters

List containing saturation curve parameters estimated using preseqR. Data-adaptively selected method: ZTNB. Contains:

  • method_used: "ZTNB" - Zero-truncated negative binomial method

  • L: 3.42e8 - Total expected distinct UMIs at saturation

  • size: 2.55 - ZTNB shape parameter

  • mu: 0.779 - ZTNB mean parameter

  • reads_norm: 23,512 - Normalization constant (reads per cell)

  • n_cells: 11,350 - Number of cells in pilot data

  • UMI_per_cell_at_saturation: 30,173 - Maximum UMI per cell at infinite sequencing depth

mapping_efficiency

Numeric. Mapping efficiency value (0.614)

Paper: CRISPR Interference-Based Platform for Multimodal Genetic Screens in Human iPSC-Derived Neurons

Author and Year: Tian et al., 2019

Journal: Neuron

Accession: GSE124703

PMID: 31422865

Details

This dataset was generated from iPSC-derived neurons using single-cell RNA sequencing with 10x Chromium technology.

Cells Used in Relative Expression Estimate: All cells in high-moi condition

See also

get_pilot_data_from_package for accessing this data programmatically

Examples

data(iPSC_neuron_Tian)
str(iPSC_neuron_Tian)
#> List of 3
#>  $ baseline_expression_stats:'data.frame':	23882 obs. of  3 variables:
#>   ..$ response_id        : chr [1:23882] "ENSG00000238009" "ENSG00000241860" "ENSG00000237491" "ENSG00000228794" ...
#>   ..$ relative_expression: num [1:23882] 9.84e-07 1.83e-06 6.47e-06 4.42e-05 5.89e-06 ...
#>   ..$ expression_size    : num [1:23882] 8.197 2.466 2.492 6.126 0.333 ...
#>  $ library_parameters       :List of 7
#>   ..$ method_used               : chr "ZTNB"
#>   ..$ L                         : num 3.42e+08
#>   ..$ size                      : num 2.55
#>   ..$ mu                        : num 0.779
#>   ..$ reads_norm                : num 23512
#>   ..$ n_cells                   : num 11350
#>   ..$ UMI_per_cell_at_saturation: num 30173
#>  $ mapping_efficiency       : num 0.614